diff --git a/src/main/java/uulm/teamname/marvelous/gamelibrary/events/EventType.java b/src/main/java/uulm/teamname/marvelous/gamelibrary/events/EventType.java
index 69c662a..44c8ff8 100644
--- a/src/main/java/uulm/teamname/marvelous/gamelibrary/events/EventType.java
+++ b/src/main/java/uulm/teamname/marvelous/gamelibrary/events/EventType.java
@@ -5,7 +5,7 @@ public enum EventType {
// GameStateEvents
Ack,
Nack,
- GameStateEvent,
+ GamestateEvent,
// CustomEvents
CustomEvent,
diff --git a/src/main/java/uulm/teamname/marvelous/gamelibrary/gamelogic/GameLogic.java b/src/main/java/uulm/teamname/marvelous/gamelibrary/gamelogic/GameLogic.java
index ee34261..5e2a525 100644
--- a/src/main/java/uulm/teamname/marvelous/gamelibrary/gamelogic/GameLogic.java
+++ b/src/main/java/uulm/teamname/marvelous/gamelibrary/gamelogic/GameLogic.java
@@ -157,7 +157,7 @@ class GameLogic {
}
}
case Req -> {
- result.add(new EventBuilder(EventType.GameStateEvent)
+ result.add(new EventBuilder(EventType.GamestateEvent)
.withEntities(state.entities.export())
.withTurnOrder((EntityID[])state.turnOrder.toArray())
.withMapSize(state.mapSize)
@@ -296,7 +296,7 @@ class GameLogic {
}
}
case TimeStone -> {
- // "👍 i approve" - the server
+ // "👍 i approve" - the server
}
case SoulStone -> {
Character target = getCharacter(state, data.targetField, data.targetEntity);
diff --git a/src/test/java/uulm/teamname/marvelous/gamelibrary/events/EventBuilderTest.java b/src/test/java/uulm/teamname/marvelous/gamelibrary/events/EventBuilderTest.java
index ac5231a..6f71c03 100644
--- a/src/test/java/uulm/teamname/marvelous/gamelibrary/events/EventBuilderTest.java
+++ b/src/test/java/uulm/teamname/marvelous/gamelibrary/events/EventBuilderTest.java
@@ -205,7 +205,7 @@ class EventBuilderTest {
.isTrue()
.withFailMessage("GameStateEvent failed check");
- var baseline = new GameStateEvent();
+ var baseline = new GamestateEvent();
baseline.type = EventType.ConsumedAPEvent;
baseline.entities = entities;
baseline.turnOrder = turns;
@@ -248,15 +248,15 @@ class EventBuilderTest {
assertThat(new EventBuilder(EventType.Nack).buildGameStateEvent().check()).isTrue();
- assertThat(new EventBuilder(EventType.Req).buildGameStateEvent().check()).isTrue();
+ // assertThat(new EventBuilder(EventType.Req).buildGameStateEvent().check()).isTrue();
- assertThat(new EventBuilder(EventType.GameStateEvent) // if properties missing throw exception
+ assertThat(new EventBuilder(EventType.GamestateEvent) // if properties missing throw exception
.withTurnOrder(turns)
.withActiveCharacter(turn)
.buildGameStateEvent()
.check()).isFalse();
- assertThat(new EventBuilder(EventType.GameStateEvent) // no exception if all properties present
+ assertThat(new EventBuilder(EventType.GamestateEvent) // no exception if all properties present
.withEntities(entities)
.withTurnOrder(turns)
.withMapSize(new IntVector2(42, 24))
diff --git a/src/main/java/uulm/teamname/marvelous/gamelibrary/events/EventBuilder.java b/src/main/java/uulm/teamname/marvelous/gamelibrary/events/EventBuilder.java
index 13ee0ef..2750de2 100644
--- a/src/main/java/uulm/teamname/marvelous/gamelibrary/events/EventBuilder.java
+++ b/src/main/java/uulm/teamname/marvelous/gamelibrary/events/EventBuilder.java
@@ -253,19 +253,19 @@ public class EventBuilder {
}
/**
* Builds a generic {@link GameStateEvent} from the values given to the builder.
*
- * - type is the {@link EventType} of the {@link GameStateEvent}
+ * - type is the {@link EventType} of the {@link GamestateEvent}
* - entities is an array of {@link Entity Entities}
* - turnOrder describes the order in which characters take turns
* - activeCharacter describes the currently active character
* - describes whether the win condition is in effect
*
*
* @return a {@link GameStateEvent} based on the builder
*/
- public GameStateEvent buildGameStateEvent() throws IllegalStateException {
- var gameStateEvent = new GameStateEvent();
+ public GamestateEvent buildGameStateEvent() throws IllegalStateException {
+ var gameStateEvent = new GamestateEvent();
gameStateEvent.type = this.type;
gameStateEvent.entities = this.entities;
gameStateEvent.turnOrder = this.turnOrder;
@@ -253,19 +253,19 @@ public class EventBuilder {
}
/**
- * Builds a generic {@link GameStateEvent} from the values given to the builder.
+ * Builds a generic {@link GamestateEvent} from the values given to the builder.
*
@@ -253,19 +253,19 @@ public class EventBuilder {
*
*
- * @return a {@link GameStateEvent} based on the builder
+ * @return a {@link GamestateEvent} based on the builder
*/
diff --git a/src/main/java/uulm/teamname/marvelous/gamelibrary/events/GameStateEvent.java b/src/main/java/uulm/teamname/marvelous/gamelibrary/events/GamestateEvent.java
similarity index 91%
rename from src/main/java/uulm/teamname/marvelous/gamelibrary/events/GameStateEvent.java
rename to src/main/java/uulm/teamname/marvelous/gamelibrary/events/GamestateEvent.java
index ed4a302..f1dd44a 100644
--- a/src/main/java/uulm/teamname/marvelous/gamelibrary/events/GameStateEvent.java
+++ b/src/main/java/uulm/teamname/marvelous/gamelibrary/events/GamestateEvent.java
@@ -7,8 +7,8 @@ import uulm.teamname.marvelous.gamelibrary.entities.EntityID;
import java.util.Arrays;
import java.util.Objects;
-/** Represents the game state event ({@link EventType#GameStateEvent}). */
-public class GameStateEvent extends Event {
+/** Represents the game state event ({@link EventType#GamestateEvent}). */
+public class GamestateEvent extends Event {
public Entity[] entities;
public EntityID[] turnOrder;
public IntVector2 mapSize;
@@ -24,7 +24,7 @@ public class GameStateEvent extends Event {
switch(type) {
// GameState needs very specific properties
- case GameStateEvent:
+ case GamestateEvent:
if (this.entities == null ||
this.turnOrder == null ||
this.mapSize == null ||
@@ -44,7 +44,7 @@ public class GameStateEvent extends Event {
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
- GameStateEvent that = (GameStateEvent) o;
+ GamestateEvent that = (GamestateEvent) o;
return Arrays.equals(entities, that.entities) && Arrays.equals(turnOrder, that.turnOrder) && Objects.equals(mapSize, that.mapSize) && Objects.equals(activeCharacter, that.activeCharacter) && Arrays.equals(stoneCooldowns, that.stoneCooldowns) && Objects.equals(winCondition, that.winCondition);
}